@@ -32,6 +32,14 @@
 
 #ifndef MP3SPLT_CDDB_H
 
+typedef struct {
+  int read_offsets;
+  int error;
+  int tracks;
+  const char *file;
+  int field_counter;
+} cddb_utils;
+
 int splt_cddb_put_splitpoints (const char *file, splt_state *state, int *error);
 
 #define MP3SPLT_CDDB_H
