@@ -35,15 +35,15 @@
 /****************************/
 /* splitpoints checks */
 
-void splt_check_splitpts_inf_song_length(splt_state *state,
+void splt_check_points_inf_song_length(splt_state *state,
     int *error);
-void splt_check_if_splitpoints_in_order(splt_state *state,
+void splt_check_if_points_in_order(splt_state *state,
     int *error);
 
 /****************************/
 /* path check */
 
-void splt_check_if_new_filename_path_correct(splt_state *state,
+void splt_check_if_fname_path_is_correct(splt_state *state,
     const char *new_filename_path, int *error);
 char *splt_check_put_dir_of_cur_song(const char *filename,
     const char *the_filename_path, int *error);
