@@ -46,21 +46,50 @@
 #include "string_utils.h"
 #include "tags_utils.h"
 #include "input_output.h"
+#include "options.h"
+#include "output_format.h"
+#include "split_points.h"
+#include "errors.h"
+#include "freedb_utils.h"
+#include "silence_utils.h"
+#include "sync_errors.h"
+#include "wrap.h"
+#include "client.h"
+#include "conversions.h"
+#include "tags_parser.h"
+#include "oformat_parser.h"
+#include "debug.h"
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
 #include <limits.h>
-#include <libintl.h>
 #include <locale.h>
 
+#ifdef ENABLE_NLS
+#  include <libintl.h>
+#endif
+
+#ifdef __WIN32__
+
+#define fseeko fseeko64
+#define ftello ftello64
+
+#else
+
 #if !HAVE_FSEEKO
 #define fseeko fseek
 #define ftello ftell
 #endif
 
-#define _(STR) dgettext(MP3SPLT_LIB_GETTEXT_DOMAIN, STR)
+#endif
+
+#ifdef ENABLE_NLS
+#  define _(STR) dgettext(MP3SPLT_LIB_GETTEXT_DOMAIN, STR)
+#else
+#  define _(STR) ((const char *)STR)
+#endif
 
 /**********************************/
 /* splt normal or syncerror split */
