@@ -141,11 +141,10 @@ FILE *splt_ogg_open_file_read(splt_state *state,
   else
   {
     //we open the file
-    file_input = splt_u_fopen(filename, "rb");
+    file_input = splt_io_fopen(filename, "rb");
     if (file_input == NULL)
     {
-      splt_t_set_strerror_msg(state);
-      splt_t_set_error_data(state,filename);
+      splt_e_set_strerror_msg_with_data(state, filename);
       *error = SPLT_ERROR_CANNOT_OPEN_FILE;
     }
   }
@@ -167,25 +166,23 @@ void splt_ogg_get_info(splt_state *state, FILE *file_input, int *error)
   else
   {
     //put file infos to client 
-    if (! splt_t_messages_locked(state))
+    if (! splt_o_messages_locked(state))
     {
       splt_ogg_state *oggstate = state->codec;
-      //ogg infos
-      char ogg_infos[2048] = { '\0' };
-      snprintf(ogg_infos, 2048, 
+
+      char ogg_infos[1024] = { '\0' };
+      snprintf(ogg_infos, 1023, 
           _(" info: Ogg Vorbis Stream - %ld - %ld Kb/s - %d channels"),
           oggstate->vd->vi->rate, oggstate->vd->vi->bitrate_nominal/1024,
           oggstate->vd->vi->channels);
-      //total time
+
       char total_time[256] = { '\0' };
       int total_seconds = (int) splt_t_get_total_time(state) / 100;
       int minutes = total_seconds / 60;
       int seconds = total_seconds % 60;
-      snprintf(total_time,256,_(" - Total time: %dm.%02ds"), minutes, seconds%60);
-      //all infos together
-      char all_infos[3072] = { '\0' };
-      snprintf(all_infos,3072,"%s%s\n",ogg_infos,total_time);
-      splt_t_put_info_message_to_client(state, all_infos);
+      snprintf(total_time, 255, _(" - Total time: %dm.%02ds"), minutes, seconds%60);
+
+      splt_c_put_info_message_to_client(state, "%s%s\n", ogg_infos, total_time);
     }
   }
 }
@@ -300,7 +297,7 @@ static int splt_ogg_update_sync(splt_state *state, ogg_sync_state *sync_in,
 
   if (ogg_sync_wrote(sync_in, bytes) != 0)
   {
-    splt_t_set_error_data(state, splt_t_get_filename_to_split(state));
+    splt_e_set_error_data(state, splt_t_get_filename_to_split(state));
     *error = SPLT_ERROR_INVALID;
     return -1;
   }
@@ -319,11 +316,11 @@ static int splt_ogg_write_pages_to_file(splt_state *state,
   {
     while (ogg_stream_flush(stream, &page))
     {
-      if (splt_u_fwrite(state, page.header, 1, page.header_len, file) < page.header_len)
+      if (splt_io_fwrite(state, page.header, 1, page.header_len, file) < page.header_len)
       {
         goto write_error;
       }
-      if (splt_u_fwrite(state, page.body, 1, page.body_len, file) < page.body_len)
+      if (splt_io_fwrite(state, page.body, 1, page.body_len, file) < page.body_len)
       {
         goto write_error;
       }
@@ -333,11 +330,11 @@ static int splt_ogg_write_pages_to_file(splt_state *state,
   {
     while (ogg_stream_pageout(stream, &page))
     {
-      if (splt_u_fwrite(state, page.header,1,page.header_len, file) < page.header_len)
+      if (splt_io_fwrite(state, page.header,1,page.header_len, file) < page.header_len)
       {
         goto write_error;
       }
-      if (splt_u_fwrite(state, page.body,1,page.body_len, file) < page.body_len)
+      if (splt_io_fwrite(state, page.body,1,page.body_len, file) < page.body_len)
       {
         goto write_error;
       }
@@ -347,7 +344,7 @@ static int splt_ogg_write_pages_to_file(splt_state *state,
   return 0;
 
 write_error:
-  splt_t_set_error_data(state, output_fname);
+  splt_e_set_error_data(state, output_fname);
   *error = SPLT_ERROR_CANT_WRITE_TO_OUTPUT_FILE;
   return -1;
 }
@@ -495,38 +492,44 @@ void splt_ogg_state_free(splt_state *state)
 //puts tags in vc
 //what happens if 'vorbis_comment_add_tag(..)' fails ?
 //- ask vorbis developers
-static void splt_ogg_v_comment(vorbis_comment *vc, char *artist,
+static void splt_ogg_v_comment(splt_state *state, vorbis_comment *vc, char *artist,
     char *album, char *title, char *tracknum, char *date, char *genre, char *comment,
     int *error)
 {
-  if (title!=NULL)
+  if (splt_o_get_int_option(state, SPLT_OPT_TAGS) == SPLT_TAGS_ORIGINAL_FILE &&
+      state->original_tags.tags_version == 0)
+  {
+    return;
+  }
+
+  if (title != NULL)
   {
     vorbis_comment_add_tag(vc, "title", splt_ogg_checkutf(title));
   }
-  if (artist!=NULL)
+  if (artist != NULL)
   {
     vorbis_comment_add_tag(vc, "artist", splt_ogg_checkutf(artist));
   }
-  if (album!=NULL)
+  if (album != NULL)
   {
     vorbis_comment_add_tag(vc, "album", splt_ogg_checkutf(album));
   }
-  if (date!=NULL)
+  if (date != NULL)
   {
-    if (strlen(date)>0)
+    if (strlen(date) > 0)
     {
       vorbis_comment_add_tag(vc, "date", date);
     }
   }
-  if (genre!=NULL)
+  if (genre != NULL)
   {
     vorbis_comment_add_tag(vc, "genre", genre);
   }
-  if (tracknum!=NULL)
+  if (tracknum != NULL)
   {
     vorbis_comment_add_tag(vc, "tracknumber", tracknum);
   }
-  if (comment!=NULL)
+  if (comment != NULL)
   {
     vorbis_comment_add_tag(vc, "comment", comment);
   }
@@ -552,76 +555,89 @@ void splt_ogg_get_original_tags(const char *filename,
   char *a = NULL,*t = NULL,*al = NULL,*da = NULL, *g = NULL,*tr = NULL,
        *com = NULL;
 
+  int has_tags = SPLT_FALSE;
+
   a = vorbis_comment_query(vc_local, "artist",0);
   if (a != NULL)
   {
-    err = splt_tu_set_original_tags_field(state,SPLT_TAGS_ARTIST, 0,a,0x0);
+    err = splt_tu_set_original_tags_field(state, SPLT_TAGS_ARTIST, a);
+    has_tags = SPLT_TRUE;
     OGG_VERIFY_ERROR();
   }
 
   t = vorbis_comment_query(vc_local, "title",0);
   if (t != NULL)
   {
-    err = splt_tu_set_original_tags_field(state,SPLT_TAGS_TITLE, 0,t,0x0);
+    err = splt_tu_set_original_tags_field(state, SPLT_TAGS_TITLE, t);
+    has_tags = SPLT_TRUE;
     OGG_VERIFY_ERROR();
   }
 
   al = vorbis_comment_query(vc_local, "album",0);
   if (al != NULL)
   {
-    err = splt_tu_set_original_tags_field(state,SPLT_TAGS_ALBUM, 0,al,0x0);
+    err = splt_tu_set_original_tags_field(state, SPLT_TAGS_ALBUM, al);
+    has_tags = SPLT_TRUE;
     OGG_VERIFY_ERROR();
   }
 
   da = vorbis_comment_query(vc_local, "date",0);
   if (da != NULL)
   {
-    err = splt_tu_set_original_tags_field(state,SPLT_TAGS_YEAR, 0,da,0x0);
+    err = splt_tu_set_original_tags_field(state, SPLT_TAGS_YEAR, da);
+    has_tags = SPLT_TRUE;
     OGG_VERIFY_ERROR();
   }
 
   g = vorbis_comment_query(vc_local, "genre",0);
   if (g != NULL)
   {
-    err = splt_tu_set_original_tags_field(state,SPLT_TAGS_GENRE, 0, g, 0x0);
+    //TODO: genre does not work
+    err = splt_tu_set_original_tags_field(state, SPLT_TAGS_GENRE, g);
+    has_tags = SPLT_TRUE;
     OGG_VERIFY_ERROR();
   }
 
   tr = vorbis_comment_query(vc_local, "tracknumber",0);
   if (tr != NULL)
   {
-    err = splt_tu_set_original_tags_field(state,SPLT_TAGS_TRACK, 0,tr, 0x0);
+    err = splt_tu_set_original_tags_field(state, SPLT_TAGS_TRACK, tr);
+    has_tags = SPLT_TRUE;
     OGG_VERIFY_ERROR();
   }
 
   com = vorbis_comment_query(vc_local, "comment",0);
   if (com != NULL)
   {
-    err = splt_tu_set_original_tags_field(state,SPLT_TAGS_COMMENT, 0,com,0x0);
+    err = splt_tu_set_original_tags_field(state, SPLT_TAGS_COMMENT, com);
+    has_tags = SPLT_TRUE;
     OGG_VERIFY_ERROR();
   }
+
+  splt_tu_set_original_tags_field(state, SPLT_TAGS_VERSION, &has_tags);
 }
 
 //puts the ogg tags
 void splt_ogg_put_tags(splt_state *state, int *error)
 {
-  splt_u_print_debug(state,"Setting ogg tags ...", 0,NULL);
+  splt_d_print_debug(state,"Setting ogg tags ...\n");
 
   splt_ogg_state *oggstate = state->codec;
 
   vorbis_comment_clear(&oggstate->vc);
 
-  if (splt_t_get_int_option(state, SPLT_OPT_TAGS) != SPLT_NO_TAGS)
+  if (splt_o_get_int_option(state, SPLT_OPT_TAGS) != SPLT_NO_TAGS)
   {
     splt_tags *tags = splt_tu_get_current_tags(state);
+
     if (tags)
     {
       char *track_string = splt_ogg_trackstring(tags->track);
       if (track_string)
       {
-        char *artist_or_performer = splt_u_get_artist_or_performer_ptr(tags);
+        char *artist_or_performer = splt_tu_get_artist_or_performer_ptr(tags);
         vorbis_comment_init(&oggstate->vc);
-        splt_ogg_v_comment(&oggstate->vc,
+        splt_ogg_v_comment(state, &oggstate->vc,
             artist_or_performer, tags->album, tags->title, track_string,
             tags->year, (char *)splt_ogg_genre_list[(int)tags->genre],
             tags->comment, error);
@@ -796,7 +812,7 @@ splt_ogg_state *splt_ogg_info(FILE *in, splt_state *state, int *error)
     int ret = ov_open(oggstate->in, &oggstate->vf, NULL, 0);
     if(ret < 0)
     {
-      splt_t_set_error_data(state,filename);
+      splt_e_set_error_data(state,filename);
       switch (ret)
       {
         case OV_EREAD:
@@ -818,7 +834,7 @@ splt_ogg_state *splt_ogg_info(FILE *in, splt_state *state, int *error)
   {
     if (*error == SPLT_ERROR_INVALID)
     {
-      splt_t_set_error_data(state,filename);
+      splt_e_set_error_data(state,filename);
     }
     splt_ogg_v_free(oggstate);
     return NULL;
@@ -1031,7 +1047,7 @@ static int splt_ogg_find_end_cutpoint(splt_state *state, ogg_stream_state *strea
     int *error, const char *output_fname, int save_end_point,
     double *sec_split_time_length)
 {
-  splt_t_put_progress_text(state,SPLT_PROGRESS_CREATE);
+  splt_c_put_progress_text(state,SPLT_PROGRESS_CREATE);
 
   //TODO: eos not set on ripped streams on last split file
 
@@ -1068,11 +1084,11 @@ static int splt_ogg_find_end_cutpoint(splt_state *state, ogg_stream_state *strea
 
     if (ogg_stream_flush(stream, &page)!=0)
     {
-      if (splt_u_fwrite(state, page.header,1,page.header_len,f) < page.header_len)
+      if (splt_io_fwrite(state, page.header,1,page.header_len,f) < page.header_len)
       {
         goto write_error;
       }
-      if (splt_u_fwrite(state, page.body,1,page.body_len,f) < page.body_len)
+      if (splt_io_fwrite(state, page.body,1,page.body_len,f) < page.body_len)
       {
         goto write_error;
       }
@@ -1085,11 +1101,11 @@ static int splt_ogg_find_end_cutpoint(splt_state *state, ogg_stream_state *strea
       // in case.
       //
       //fprintf(stderr, 'Warning: First audio packet didn't fit into page. File may not decode correctly\n")'
-      if (splt_u_fwrite(state, page.header,1,page.header_len,f) < page.header_len)
+      if (splt_io_fwrite(state, page.header,1,page.header_len,f) < page.header_len)
       {
         goto write_error;
       }
-      if (splt_u_fwrite(state, page.body,1,page.body_len,f) < page.body_len)
+      if (splt_io_fwrite(state, page.body,1,page.body_len,f) < page.body_len)
       {
         goto write_error;
       }
@@ -1110,11 +1126,11 @@ static int splt_ogg_find_end_cutpoint(splt_state *state, ogg_stream_state *strea
 
       if (ogg_stream_flush(stream, &page)!=0)
       {
-        if (splt_u_fwrite(state, page.header,1,page.header_len,f) < page.header_len)
+        if (splt_io_fwrite(state, page.header,1,page.header_len,f) < page.header_len)
         {
           goto write_error;
         }
-        if (splt_u_fwrite(state, page.body,1,page.body_len,f) < page.body_len)
+        if (splt_io_fwrite(state, page.body,1,page.body_len,f) < page.body_len)
         {
           goto write_error;
         }
@@ -1187,17 +1203,17 @@ static int splt_ogg_find_end_cutpoint(splt_state *state, ogg_stream_state *strea
                   packet.packetno = packetnum++;
 
                   //progress
-                  if ((splt_t_get_int_option(state,SPLT_OPT_SPLIT_MODE)
+                  if ((splt_o_get_int_option(state,SPLT_OPT_SPLIT_MODE)
                         == SPLT_OPTION_SILENCE_MODE) ||
-                      (!splt_t_get_int_option(state,SPLT_OPT_AUTO_ADJUST)))
+                      (!splt_o_get_int_option(state,SPLT_OPT_AUTO_ADJUST)))
                   {
-                    splt_t_update_progress(state, (double)page_granpos,
+                    splt_c_update_progress(state, (double)page_granpos,
                         (double)cutpoint,
                         1,0,SPLT_DEFAULT_PROGRESS_RATE);
                   }
                   else
                   {
-                    splt_t_update_progress(state, (double)page_granpos,
+                    splt_c_update_progress(state, (double)page_granpos,
                         (double)cutpoint,
                         2,0,SPLT_DEFAULT_PROGRESS_RATE);
                   }
@@ -1227,7 +1243,7 @@ static int splt_ogg_find_end_cutpoint(splt_state *state, ogg_stream_state *strea
               if (splt_ogg_scan_silence(state,
                     (2 * adjust), threshold, 0.f, 0, &page, current_granpos, error) > 0)
               {
-                cutpoint = (splt_u_silence_position(state->silence_list, 
+                cutpoint = (splt_siu_silence_position(state->silence_list, 
                       oggstate->off) * oggstate->vi->rate);
               }
               else
@@ -1237,10 +1253,10 @@ static int splt_ogg_find_end_cutpoint(splt_state *state, ogg_stream_state *strea
 
               *sec_split_time_length = cutpoint / oggstate->vi->rate;
 
-              splt_t_ssplit_free(&state->silence_list);
+              splt_siu_ssplit_free(&state->silence_list);
               adjust = 0;
               progress_adjust = 0;
-              splt_t_put_progress_text(state, SPLT_PROGRESS_CREATE);
+              splt_c_put_progress_text(state, SPLT_PROGRESS_CREATE);
 
               //check error of 'splt_ogg_scan_silence'
               if (*error < 0) { return -1; }
@@ -1364,7 +1380,7 @@ static int splt_ogg_find_end_cutpoint(splt_state *state, ogg_stream_state *strea
   return 0;
 
 write_error:
-  splt_t_set_error_data(state, output_fname);
+  splt_e_set_error_data(state, output_fname);
   *error = SPLT_ERROR_CANT_WRITE_TO_OUTPUT_FILE;
   return -1;
 }
@@ -1426,7 +1442,7 @@ double splt_ogg_split(const char *output_fname, splt_state *state,
     }
   }
 
-  if (! splt_t_get_int_option(state, SPLT_OPT_PRETEND_TO_SPLIT))
+  if (! splt_o_get_int_option(state, SPLT_OPT_PRETEND_TO_SPLIT))
   {
     //- means stdout
     if (strcmp(output_fname, "-")==0)
@@ -1438,10 +1454,9 @@ double splt_ogg_split(const char *output_fname, splt_state *state,
     }
     else
     {
-      if (!(oggstate->out = splt_u_fopen(output_fname, "wb")))
+      if (!(oggstate->out = splt_io_fopen(output_fname, "wb")))
       {
-        splt_t_set_strerror_msg(state);
-        splt_t_set_error_data(state, output_fname);
+        splt_e_set_strerror_msg_with_data(state, output_fname);
         *error = SPLT_ERROR_CANNOT_OPEN_DEST_FILE;
         return sec_end_time;
       }
@@ -1489,8 +1504,7 @@ end:
     {
       if (fclose(oggstate->out) != 0)
       {
-        splt_t_set_strerror_msg(state);
-        splt_t_set_error_data(state, output_fname);
+        splt_e_set_strerror_msg_with_data(state, output_fname);
         *error = SPLT_ERROR_CANNOT_CLOSE_FILE;
       }
     }
@@ -1554,7 +1568,7 @@ int splt_ogg_scan_silence(splt_state *state, short seconds,
     float threshold, float min, short output, 
     ogg_page *page, ogg_int64_t granpos, int *error)
 {
-  splt_t_put_progress_text(state,SPLT_PROGRESS_SCAN_SILENCE);
+  splt_c_put_progress_text(state,SPLT_PROGRESS_SCAN_SILENCE);
   splt_ogg_state *oggstate = state->codec;
 
   //unsigned long count = 0;
@@ -1569,7 +1583,7 @@ int splt_ogg_scan_silence(splt_state *state, short seconds,
   short first, flush = 0;
   off_t position = ftello(oggstate->in); // Some backups
   int saveW = oggstate->prevW;
-  float th = splt_u_convertfromdB(threshold);
+  float th = splt_co_convert_from_dB(threshold);
 
   ogg_sync_init(&oy);
   ogg_stream_init(&os, oggstate->serial);
@@ -1692,7 +1706,7 @@ int splt_ogg_scan_silence(splt_state *state, short seconds,
                     if ((e_position - b_position - min) >= 0.f)
                     {
                       int err = SPLT_OK;
-                      if (splt_t_ssplit_new(&state->silence_list, b_position, e_position, len, &err) == -1)
+                      if (splt_siu_ssplit_new(&state->silence_list, b_position, e_position, len, &err) == -1)
                       {
                         found = -1;
                         goto function_end;
@@ -1725,7 +1739,7 @@ int splt_ogg_scan_silence(splt_state *state, short seconds,
             else
             {
               *error = SPLT_ERROR_INVALID;
-              splt_t_set_error_data(state,filename);
+              splt_e_set_error_data(state,filename);
               found = -1;
               goto function_end;
             }
@@ -1764,7 +1778,7 @@ int splt_ogg_scan_silence(splt_state *state, short seconds,
 
       //if (count++ % X == 0)
       {
-        float level = splt_u_convert2dB(oggstate->temp_level);
+        float level = splt_co_convert_to_dB(oggstate->temp_level);
         if (state->split.get_silence_level)
         {
           long time = (long) (((double) pos / oggstate->vi->rate) * 100.0);
@@ -1784,19 +1798,19 @@ int splt_ogg_scan_silence(splt_state *state, short seconds,
         state->split.p_bar->silence_found_tracks = found;
       }
 
-      if (splt_t_get_int_option(state,SPLT_OPT_SPLIT_MODE) == SPLT_OPTION_SILENCE_MODE)
+      if (splt_o_get_int_option(state,SPLT_OPT_SPLIT_MODE) == SPLT_OPTION_SILENCE_MODE)
       {
         if (splt_t_split_is_canceled(state))
         {
           eos = 1;
         }
-        splt_t_update_progress(state,(double)pos * 100,
+        splt_c_update_progress(state,(double)pos * 100,
             (double)(oggstate->len),
             1,0,SPLT_DEFAULT_PROGRESS_RATE2);
       }
       else
       {
-        splt_t_update_progress(state,(double)begin,
+        splt_c_update_progress(state,(double)begin,
             (double)end, 2,0.5,SPLT_DEFAULT_PROGRESS_RATE2);
       }
     }
@@ -1813,8 +1827,7 @@ function_end:
   oggstate->prevW = saveW;
   if (fseeko(oggstate->in, position, SEEK_SET) == -1)
   {
-    splt_t_set_strerror_msg(state);
-    splt_t_set_error_data(state, filename);
+    splt_e_set_strerror_msg_with_data(state, filename);
     *error = SPLT_ERROR_SEEKING_FILE;
     found = -1;
   }
@@ -1858,7 +1871,7 @@ void splt_pl_set_plugin_info(splt_plugin_info *info, int *error)
     return;
   }
 
-  info->upper_extension = splt_u_str_to_upper(info->extension, error);
+  info->upper_extension = splt_su_str_to_upper(info->extension, error);
 }
 
 //check if file is ogg vorbis
@@ -1877,10 +1890,9 @@ int splt_pl_check_plugin_is_for_file(splt_state *state, int *error)
 
   FILE *file_input = NULL;
 
-  if ((file_input = splt_u_fopen(filename, "rb")) == NULL)
+  if ((file_input = splt_io_fopen(filename, "rb")) == NULL)
   {
-    splt_t_set_strerror_msg(state);
-    splt_t_set_error_data(state,filename);
+    splt_e_set_strerror_msg_with_data(state, filename);
     *error = SPLT_ERROR_CANNOT_OPEN_FILE;
   }
   else
@@ -1897,8 +1909,7 @@ int splt_pl_check_plugin_is_for_file(splt_state *state, int *error)
       {
         if (fclose(file_input) != 0)
         {
-          splt_t_set_strerror_msg(state);
-          splt_t_set_error_data(state, filename);
+          splt_e_set_strerror_msg_with_data(state, filename);
           *error = SPLT_ERROR_CANNOT_CLOSE_FILE;
         }
       }
@@ -1914,14 +1925,12 @@ void splt_pl_init(splt_state *state, int *error)
   FILE *file_input = NULL;
   char *filename = splt_t_get_filename_to_split(state);
 
-  if (splt_t_is_stdin(state))
+  if (splt_io_input_is_stdin(state))
   {
     if (filename[1] == '\0')
     {
-      char message[1024] = { '\0' };
-      snprintf(message, 1024,
+      splt_c_put_info_message_to_client(state, 
           _(" warning: stdin 'o-' is supposed to be ogg stream.\n"));
-      splt_t_put_info_message_to_client(state, message);
     }
   }
 
@@ -1932,7 +1941,7 @@ void splt_pl_init(splt_state *state, int *error)
     if (*error >= 0)
     {
       splt_ogg_state *oggstate = state->codec;
-      oggstate->off = splt_t_get_float_option(state,SPLT_OPT_PARAM_OFFSET);
+      oggstate->off = splt_o_get_float_option(state,SPLT_OPT_PARAM_OFFSET);
     }
   }
 }
@@ -1949,7 +1958,6 @@ double splt_pl_split(splt_state *state, const char *final_fname,
 
   if (*error >= 0)
   {
-    //effective ogg split
     return splt_ogg_split(final_fname, state,
         begin_point, end_point,
         !state->options.option_input_not_seekable,
@@ -1962,9 +1970,9 @@ double splt_pl_split(splt_state *state, const char *final_fname,
 
 int splt_pl_scan_silence(splt_state *state, int *error)
 {
-  float offset = splt_t_get_float_option(state,SPLT_OPT_PARAM_OFFSET);
-  float threshold = splt_t_get_float_option(state, SPLT_OPT_PARAM_THRESHOLD);
-  float min_length = splt_t_get_float_option(state, SPLT_OPT_PARAM_MIN_LENGTH);
+  float offset = splt_o_get_float_option(state,SPLT_OPT_PARAM_OFFSET);
+  float threshold = splt_o_get_float_option(state, SPLT_OPT_PARAM_THRESHOLD);
+  float min_length = splt_o_get_float_option(state, SPLT_OPT_PARAM_MIN_LENGTH);
   int found = 0;
 
   splt_ogg_state *oggstate = state->codec;
@@ -1978,7 +1986,7 @@ int splt_pl_scan_silence(splt_state *state, int *error)
 
 void splt_pl_set_original_tags(splt_state *state, int *error)
 {
-  splt_u_print_debug(state,"Taking ogg original tags...",0,NULL);
+  splt_d_print_debug(state,"Taking ogg original tags... \n");
   char *filename = splt_t_get_filename_to_split(state);
   splt_ogg_get_original_tags(filename, state, error);
 }
