@@ -42,14 +42,21 @@
 #include "win32.h"
 #endif
 
-int splt_p_append_plugin_scan_dir(splt_state *state, char *dir)
+static int splt_p_alloc_init_new_plugin(splt_plugins *pl);
+static void splt_p_free_plugin_data_info(splt_plugin_data *pl_data);
+static void splt_p_free_plugin_data(splt_plugin_data *pl_data);
+
+int splt_p_append_plugin_scan_dir(splt_state *state, const char *dir)
 {
+  if (dir == NULL)
+  {
+    return SPLT_OK;
+  }
+
   splt_plugins *pl = state->plug;
 
-  //allocate memory for another char * pointer
   if (pl->plugins_scan_dirs == NULL)
   {
-    //allocate memory
     pl->plugins_scan_dirs = malloc(sizeof(char *));
   }
   else
@@ -61,48 +68,21 @@ int splt_p_append_plugin_scan_dir(splt_state *state, char *dir)
   {
     return SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
   }
-  pl->plugins_scan_dirs[pl->number_of_dirs_to_scan] = NULL;
 
-  //allocate memory for this directory name
-  pl->plugins_scan_dirs[pl->number_of_dirs_to_scan] = malloc(sizeof(char) * (strlen(dir)+1));
+  size_t dir_size = strlen(dir) + 1;
+
+  pl->plugins_scan_dirs[pl->number_of_dirs_to_scan] = malloc(sizeof(char) * dir_size);
   if (pl->plugins_scan_dirs[pl->number_of_dirs_to_scan] == NULL)
   {
     return SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
   }
 
-  snprintf(pl->plugins_scan_dirs[pl->number_of_dirs_to_scan],strlen(dir)+1,"%s",dir);
-
+  snprintf(pl->plugins_scan_dirs[pl->number_of_dirs_to_scan], dir_size, "%s", dir);
   pl->number_of_dirs_to_scan++;
 
   return SPLT_OK;
 }
 
-//sets the plugin scan directories
-int splt_p_set_default_plugins_scan_dirs(splt_state *state)
-{
-  int err = SPLT_OK;
-
-  //temporary variable that we use to set the default directories
-  char temp[2048] = { '\0' };
-
-#ifndef __WIN32__
-  //we put the default plugin directory
-  snprintf(temp,2048,"%s",SPLT_PLUGINS_DIR);
-  if ((err = splt_p_append_plugin_scan_dir(state, temp)) != SPLT_OK) { return err; }
-#endif
-
-  //we put the home libmp3splt home directory
-  snprintf(temp,2048,"%s%c%s",getenv("HOME"),SPLT_DIRCHAR,".libmp3splt");
-  if ((err = splt_p_append_plugin_scan_dir(state, temp)) != SPLT_OK) { return err; }
-
-  //we put the current directory
-  memset(temp,'\0',2048);
-  snprintf(temp,2048,".%c",SPLT_DIRCHAR);
-  if ((err = splt_p_append_plugin_scan_dir(state, temp)) != SPLT_OK) { return err; }
-
-  return err;
-}
-
 //function to filter the plugin files
 static int splt_p_filter_plugin_files(const struct dirent *de)
 {
@@ -116,7 +96,7 @@ static int splt_p_filter_plugin_files(const struct dirent *de)
       //if the name starts with splt_and contains .so or .sl or .dll or .dylib
       if (strncmp(file,"libsplt_",8) == 0)
       {
-        splt_u_print_debug(NULL, "Looking at the file ",0, file);
+        splt_d_print_debug(NULL, "Looking at the file _%s_\n", file);
 
         p_start = strchr(file,'.');
 
@@ -162,7 +142,7 @@ static int splt_p_scan_dir_for_plugins(splt_state *state, splt_plugins *pl, cons
   struct dirent **files = NULL;
 
   int number_of_files = 0;
-  //scan the directory
+  errno = 0;
   number_of_files = scandir(directory, &files, splt_p_filter_plugin_files, alphasort);
   int directory_len = strlen(directory);
   int new_number_of_files = number_of_files;
@@ -217,7 +197,7 @@ static int splt_p_scan_dir_for_plugins(splt_state *state, splt_plugins *pl, cons
       //if we don't have a plugin from the same file, add this new plugin
       if (! we_already_have_this_plugin_file)
       {
-        int alloc_err = splt_t_alloc_init_new_plugin(pl);
+        int alloc_err = splt_p_alloc_init_new_plugin(pl);
         if (alloc_err < 0)
         {
           return_value = alloc_err;
@@ -297,7 +277,8 @@ static int splt_p_find_plugins(splt_state *state)
   {
     if (pl->plugins_scan_dirs[i] != NULL)
     {
-      splt_u_print_debug(state,"Scanning plugins in the directory ",0, pl->plugins_scan_dirs[i]);
+      splt_d_print_debug(state,"Scanning plugins in the directory _%s_\n",
+          pl->plugins_scan_dirs[i]);
 
       //don't check if directory exists if the directory is ./ on unix-like
       //OSes or .\\ on windows
@@ -321,7 +302,7 @@ int splt_p_move_replace_plugin_data(splt_state *state, int old, int new)
 {
   splt_plugins *pl = state->plug;
 
-  splt_t_free_plugin_data(&pl->data[new]);
+  splt_p_free_plugin_data(&pl->data[new]);
 
   pl->data[new].func = malloc(sizeof(splt_plugin_func));
   if (pl->data[new].func == NULL)
@@ -339,7 +320,7 @@ int splt_p_move_replace_plugin_data(splt_state *state, int old, int new)
   snprintf(pl->data[new].plugin_filename, plugin_fname_len, "%s",
       pl->data[old].plugin_filename);
 
-  splt_t_free_plugin_data(&pl->data[old]);
+  splt_p_free_plugin_data(&pl->data[old]);
 
   return SPLT_OK;
 }
@@ -375,15 +356,16 @@ static int splt_p_open_get_valid_plugins(splt_state *state)
   int i = 0;
   for (i = 0;i < pl->number_of_plugins_found;i++)
   {
-    splt_u_print_debug(state,"\nTrying to open the plugin ...",0,pl->data[i].plugin_filename);
+    splt_d_print_debug(state,"\nTrying to open the plugin _%s_ ...\n",
+        pl->data[i].plugin_filename);
 
     //ltdl currently does not supports windows unicode path/filename
     pl->data[i].plugin_handle = lt_dlopen(pl->data[i].plugin_filename);
     //error
     if (! pl->data[i].plugin_handle)
     {
-      splt_u_print_debug(state,"Error loading the plugin",0,pl->data[i].plugin_filename);
-      splt_u_print_debug(state," - error message from libltdl: ",0,lt_dlerror());
+      splt_d_print_debug(state,"Error loading the plugin _%s_\n", pl->data[i].plugin_filename);
+      splt_d_print_debug(state," - error message from libltdl: _%s_\n", lt_dlerror());
 
       //keep the index of this failed plugin in order to remove it
       //afterwards
@@ -400,7 +382,7 @@ static int splt_p_open_get_valid_plugins(splt_state *state)
     }
     else
     {
-      splt_u_print_debug(state," - success !",0,NULL);
+      splt_d_print_debug(state," - success !\n");
 
       pl->data[i].func->set_plugin_info =
         lt_dlsym(pl->data[i].plugin_handle, "splt_pl_set_plugin_info");
@@ -411,13 +393,13 @@ static int splt_p_open_get_valid_plugins(splt_state *state)
 
       //look if we already have a plugin with the same name
       int j = 0;
-      splt_t_set_current_plugin(state, i);
+      splt_p_set_current_plugin(state, i);
       const char *current_plugin_name = splt_p_get_name(state, &error);
       for (j = 0;j < i;j++)
       {
         if (pl->data[j].plugin_handle)
         {
-          splt_t_set_current_plugin(state, j);
+          splt_p_set_current_plugin(state, j);
           const char *plugin_name = splt_p_get_name(state, &error);
           //if we do have one with the same name,
           if (strcmp(plugin_name,current_plugin_name) == 0)
@@ -462,12 +444,12 @@ static int splt_p_open_get_valid_plugins(splt_state *state)
   {
     int index_to_remove = plugin_index_to_remove[i] - left_shift;
 
-    splt_u_print_debug(state,"Removing the plugin ",0,
+    splt_d_print_debug(state,"Removing the plugin _%s_\n",
         pl->data[index_to_remove].plugin_filename);
 
     if (i == number_of_plugins_to_remove-1)
     {
-      splt_t_free_plugin_data(&pl->data[index_to_remove]);
+      splt_p_free_plugin_data(&pl->data[index_to_remove]);
     }
     else
     {
@@ -501,7 +483,7 @@ int splt_p_find_get_plugins_data(splt_state *state)
 {
   int return_value = SPLT_OK;
 
-  splt_u_print_debug(state,"\nSearching for plugins ...",0,NULL);
+  splt_d_print_debug(state,"\nSearching for plugins ...\n");
 
   //find the plugins
   return_value = splt_p_find_plugins(state);
@@ -518,10 +500,8 @@ int splt_p_find_get_plugins_data(splt_state *state)
 
   if (return_value >= 0)
   {
-    //debug
     splt_plugins *pl = state->plug;
-    splt_u_print_debug(state,"\nNumber of plugins found = ",pl->number_of_plugins_found,NULL);
-    splt_u_print_debug(state,"",0,NULL);
+    splt_d_print_debug(state,"\nNumber of plugins found: _%d_\n",pl->number_of_plugins_found);
     int i = 0;
     int err = 0;
     for (i = 0;i < pl->number_of_plugins_found;i++)
@@ -550,25 +530,24 @@ int splt_p_find_get_plugins_data(splt_state *state)
         lt_dlsym(pl->data[i].plugin_handle, "splt_pl_set_plugin_info");
       if (pl->data[i].func->set_plugin_info != NULL)
       {
-        splt_t_free_plugin_data_info(&pl->data[i]);
+        splt_p_free_plugin_data_info(&pl->data[i]);
         pl->data[i].func->set_plugin_info(&pl->data[i].info,&err);
       }
 
-      splt_t_set_current_plugin(state, i);
+      splt_p_set_current_plugin(state, i);
       if (pl->data[i].plugin_filename != NULL)
       {
-        splt_u_print_debug(state,"plugin filename = ",0,pl->data[i].plugin_filename);
+        splt_d_print_debug(state,"plugin filename = _%s_\n", pl->data[i].plugin_filename);
       }
       const char *temp = splt_p_get_name(state, &err);
-      splt_u_print_debug(state,"plugin name = ",0,temp);
+      splt_d_print_debug(state,"plugin name = _%s_\n", temp);
       float version = splt_p_get_version(state, &err);
-      splt_u_print_debug(state,"plugin version = ", version, NULL);
+      splt_d_print_debug(state,"plugin version = _%d_\n", version);
       temp = splt_p_get_extension(state,&err);
-      splt_u_print_debug(state,"extension = ",0,temp);
-      splt_u_print_debug(state,"",0,NULL);
+      splt_d_print_debug(state,"extension = _%s_\n\n", temp);
     }
   }
-  splt_t_set_current_plugin(state, -1);
+  splt_p_set_current_plugin(state, -1);
 
   return return_value;
 }
@@ -578,7 +557,7 @@ int splt_p_find_get_plugins_data(splt_state *state)
 float splt_p_get_version(splt_state *state, int *error)
 {
   splt_plugins *pl = state->plug;
-  int current_plugin = splt_t_get_current_plugin(state);
+  int current_plugin = splt_p_get_current_plugin(state);
   if ((current_plugin < 0) || (current_plugin >= pl->number_of_plugins_found))
   {
     *error = SPLT_ERROR_NO_PLUGIN_FOUND;
@@ -593,7 +572,7 @@ float splt_p_get_version(splt_state *state, int *error)
 const char *splt_p_get_name(splt_state *state, int *error)
 {
   splt_plugins *pl = state->plug;
-  int current_plugin = splt_t_get_current_plugin(state);
+  int current_plugin = splt_p_get_current_plugin(state);
   if ((current_plugin < 0) || (current_plugin >= pl->number_of_plugins_found))
   {
     *error = SPLT_ERROR_NO_PLUGIN_FOUND;
@@ -608,7 +587,7 @@ const char *splt_p_get_name(splt_state *state, int *error)
 const char *splt_p_get_extension(splt_state *state, int *error)
 {
   splt_plugins *pl = state->plug;
-  int current_plugin = splt_t_get_current_plugin(state);
+  int current_plugin = splt_p_get_current_plugin(state);
   if ((current_plugin < 0) || (current_plugin >= pl->number_of_plugins_found))
   {
     *error = SPLT_ERROR_NO_PLUGIN_FOUND;
@@ -623,7 +602,7 @@ const char *splt_p_get_extension(splt_state *state, int *error)
 const char *splt_p_get_upper_extension(splt_state *state, int *error)
 {
   splt_plugins *pl = state->plug;
-  int current_plugin = splt_t_get_current_plugin(state);
+  int current_plugin = splt_p_get_current_plugin(state);
   if ((current_plugin < 0) || (current_plugin >= pl->number_of_plugins_found))
   {
     *error = SPLT_ERROR_NO_PLUGIN_FOUND;
@@ -640,7 +619,7 @@ const char *splt_p_get_upper_extension(splt_state *state, int *error)
 int splt_p_check_plugin_is_for_file(splt_state *state, int *error)
 {
   splt_plugins *pl = state->plug;
-  int current_plugin = splt_t_get_current_plugin(state);
+  int current_plugin = splt_p_get_current_plugin(state);
   if ((current_plugin < 0) || (current_plugin >= pl->number_of_plugins_found))
   {
     *error = SPLT_ERROR_NO_PLUGIN_FOUND;
@@ -663,7 +642,7 @@ int splt_p_check_plugin_is_for_file(splt_state *state, int *error)
 void splt_p_search_syncerrors(splt_state *state, int *error)
 {
   splt_plugins *pl = state->plug;
-  int current_plugin = splt_t_get_current_plugin(state);
+  int current_plugin = splt_p_get_current_plugin(state);
   if ((current_plugin < 0) || (current_plugin >= pl->number_of_plugins_found))
   {
     *error = SPLT_ERROR_NO_PLUGIN_FOUND;
@@ -673,8 +652,7 @@ void splt_p_search_syncerrors(splt_state *state, int *error)
   {
     if (pl->data[current_plugin].func->search_syncerrors != NULL)
     {
-      //we free previous sync errors if necesssary
-      splt_t_serrors_free(state);
+      splt_se_serrors_free(state);
       pl->data[current_plugin].func->search_syncerrors(state, error);
     }
     else
@@ -687,7 +665,7 @@ void splt_p_search_syncerrors(splt_state *state, int *error)
 void splt_p_dewrap(splt_state *state, int listonly, const char *dir, int *error)
 {
   splt_plugins *pl = state->plug;
-  int current_plugin = splt_t_get_current_plugin(state);
+  int current_plugin = splt_p_get_current_plugin(state);
   if ((current_plugin < 0) || (current_plugin >= pl->number_of_plugins_found))
   {
     *error = SPLT_ERROR_NO_PLUGIN_FOUND;
@@ -710,7 +688,7 @@ double splt_p_split(splt_state *state, const char *final_fname, double begin_poi
     double end_point, int *error, int save_end_point)
 {
   splt_plugins *pl = state->plug;
-  int current_plugin = splt_t_get_current_plugin(state);
+  int current_plugin = splt_p_get_current_plugin(state);
   if ((current_plugin < 0) || (current_plugin >= pl->number_of_plugins_found))
   {
     *error = SPLT_ERROR_NO_PLUGIN_FOUND;
@@ -719,7 +697,10 @@ double splt_p_split(splt_state *state, const char *final_fname, double begin_poi
   else
   {
     int err = SPLT_OK;
-    splt_u_create_output_dirs_if_necessary(state, final_fname, &err);
+
+    splt_d_print_debug(state, "split creating directories of final fname ... _%s_\n", final_fname);
+
+    splt_io_create_output_dirs_if_necessary(state, final_fname, &err);
     if (err < 0) { *error = err; return end_point; }
 
     if (pl->data[current_plugin].func->split != NULL)
@@ -727,7 +708,7 @@ double splt_p_split(splt_state *state, const char *final_fname, double begin_poi
       double new_end_point = pl->data[current_plugin].func->split(state, final_fname,
           begin_point, end_point, error, save_end_point);
 
-      splt_u_print_debug(state, "New end point after split ...",new_end_point,NULL);
+      splt_d_print_debug(state, "New end point after split = _%lf_\n", new_end_point);
 
       return new_end_point;
     }
@@ -743,7 +724,7 @@ double splt_p_split(splt_state *state, const char *final_fname, double begin_poi
 void splt_p_init(splt_state *state, int *error)
 {
   splt_plugins *pl = state->plug;
-  int current_plugin = splt_t_get_current_plugin(state);
+  int current_plugin = splt_p_get_current_plugin(state);
   if ((current_plugin < 0) || (current_plugin >= pl->number_of_plugins_found))
   {
     *error = SPLT_ERROR_NO_PLUGIN_FOUND;
@@ -765,7 +746,7 @@ void splt_p_init(splt_state *state, int *error)
 void splt_p_end(splt_state *state, int *error)
 {
   splt_plugins *pl = state->plug;
-  int current_plugin = splt_t_get_current_plugin(state);
+  int current_plugin = splt_p_get_current_plugin(state);
   if ((current_plugin < 0) || (current_plugin >= pl->number_of_plugins_found))
   {
     *error = SPLT_ERROR_NO_PLUGIN_FOUND;
@@ -788,7 +769,7 @@ int splt_p_simple_split(splt_state *state, const char *output_fname, off_t begin
     off_t end)
 {
   splt_plugins *pl = state->plug;
-  int current_plugin = splt_t_get_current_plugin(state);
+  int current_plugin = splt_p_get_current_plugin(state);
   int error = SPLT_OK;
   if ((current_plugin < 0) || (current_plugin >= pl->number_of_plugins_found))
   {
@@ -813,7 +794,7 @@ int splt_p_simple_split(splt_state *state, const char *output_fname, off_t begin
 int splt_p_scan_silence(splt_state *state, int *error)
 {
   splt_plugins *pl = state->plug;
-  int current_plugin = splt_t_get_current_plugin(state);
+  int current_plugin = splt_p_get_current_plugin(state);
   if ((current_plugin < 0) || (current_plugin >= pl->number_of_plugins_found))
   {
     *error = SPLT_ERROR_NO_PLUGIN_FOUND;
@@ -837,7 +818,7 @@ int splt_p_scan_silence(splt_state *state, int *error)
 void splt_p_set_original_tags(splt_state *state, int *error)
 {
   splt_plugins *pl = state->plug;
-  int current_plugin = splt_t_get_current_plugin(state);
+  int current_plugin = splt_p_get_current_plugin(state);
   if ((current_plugin < 0) || (current_plugin >= pl->number_of_plugins_found))
   {
     *error = SPLT_ERROR_NO_PLUGIN_FOUND;
@@ -852,3 +833,194 @@ void splt_p_set_original_tags(splt_state *state, int *error)
   }
 }
 
+static int splt_p_set_default_plugins_scan_dirs(splt_state *state)
+{
+  int err = SPLT_OK;
+  char *dir = NULL;
+
+#ifndef __WIN32__
+  err = splt_p_append_plugin_scan_dir(state, SPLT_PLUGINS_DIR);
+  if (err < 0) { return err; }
+#endif
+
+  err = splt_su_append_str(&dir, getenv("HOME"), SPLT_DIRSTR, ".libmp3splt", NULL);
+  if (err < 0) { goto end; }
+  err = splt_p_append_plugin_scan_dir(state, dir);
+  free(dir);
+  dir = NULL;
+
+  err = splt_su_append_str(&dir, ".", SPLT_DIRSTR, NULL);
+  if (err < 0) { goto end; }
+  err = splt_p_append_plugin_scan_dir(state, dir);
+
+end:
+  if (dir)
+  {
+    free(dir);
+    dir = NULL;
+  }
+
+  return err;
+}
+
+int splt_p_set_default_values(splt_state *state)
+{
+  state->plug->plugins_scan_dirs = NULL;
+  state->plug->number_of_plugins_found = 0;
+  state->plug->data = NULL;
+  state->plug->number_of_dirs_to_scan = 0;
+
+  return splt_p_set_default_plugins_scan_dirs(state);
+}
+
+static int splt_p_alloc_init_new_plugin(splt_plugins *pl)
+{
+  int return_value = SPLT_OK;
+
+  if (pl->data == NULL)
+  {
+    pl->data = malloc(sizeof(splt_plugin_data) * (pl->number_of_plugins_found+1));
+    if (pl->data == NULL)
+    {
+      return_value = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
+      return return_value;
+    }
+  }
+  else
+  {
+    pl->data = realloc(pl->data,sizeof(splt_plugin_data) *
+        (pl->number_of_plugins_found+1));
+    if (pl->data == NULL)
+    {
+      return_value = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
+      return return_value;
+    }
+  }
+
+  pl->data[pl->number_of_plugins_found].func = NULL;
+  pl->data[pl->number_of_plugins_found].plugin_handle = NULL;
+  pl->data[pl->number_of_plugins_found].info.version = 0;
+  pl->data[pl->number_of_plugins_found].info.name = NULL;
+  pl->data[pl->number_of_plugins_found].info.extension = NULL;
+  pl->data[pl->number_of_plugins_found].info.upper_extension = NULL;
+  pl->data[pl->number_of_plugins_found].plugin_filename = NULL;
+
+  return return_value;
+}
+
+static void splt_p_free_plugin_data_info(splt_plugin_data *pl_data)
+{
+  if (pl_data->info.name)
+  {
+    free(pl_data->info.name);
+    pl_data->info.name = NULL;
+  }
+  if (pl_data->info.extension)
+  {
+    free(pl_data->info.extension);
+    pl_data->info.extension = NULL;
+  }
+  if (pl_data->info.upper_extension)
+  {
+    free(pl_data->info.upper_extension);
+    pl_data->info.upper_extension = NULL;
+  }
+}
+
+static void splt_p_free_plugin_data(splt_plugin_data *pl_data)
+{
+  splt_p_free_plugin_data_info(pl_data);
+  if (pl_data->plugin_filename)
+  {
+    free(pl_data->plugin_filename);
+    pl_data->plugin_filename = NULL;
+  }
+  if (pl_data->plugin_handle)
+  {
+    lt_dlclose(pl_data->plugin_handle);
+    pl_data->plugin_handle = NULL;
+  }
+  if (pl_data->func)
+  {
+    free(pl_data->func);
+    pl_data->func = NULL;
+  }
+}
+
+void splt_p_free_plugins(splt_state *state)
+{
+  splt_plugins *pl = state->plug;
+  int i = 0;
+
+  if (pl->plugins_scan_dirs)
+  {
+    for (i = 0;i < pl->number_of_dirs_to_scan;i++)
+    {
+      if (pl->plugins_scan_dirs[i])
+      {
+        free(pl->plugins_scan_dirs[i]);
+        pl->plugins_scan_dirs[i] = NULL;
+      }
+    }
+    free(pl->plugins_scan_dirs);
+    pl->plugins_scan_dirs = NULL;
+    pl->number_of_dirs_to_scan = 0;
+  }
+  if (pl->data)
+  {
+    for (i = 0;i < pl->number_of_plugins_found;i++)
+    {
+      splt_p_free_plugin_data(&pl->data[i]);
+    }
+    free(pl->data);
+    pl->data = NULL;
+    pl->number_of_plugins_found = 0;
+  }
+}
+
+void splt_p_set_current_plugin(splt_state *state, int current_plugin)
+{
+  //-1 means no plugin
+  if (current_plugin >= -1)
+  {
+    state->current_plugin = current_plugin;
+  }
+  else
+  {
+    splt_e_error(SPLT_IERROR_INT,__func__, current_plugin, NULL);
+  }
+}
+
+int splt_p_get_current_plugin(splt_state *state)
+{
+  return state->current_plugin;
+}
+
+int splt_p_file_is_supported_by_plugins(splt_state *state, const char *fname)
+{
+  splt_plugins *pl = state->plug;
+
+  int fname_length = strlen(fname);
+  if (fname_length > 3)
+  {
+    char *ptr_to_compare = strrchr(fname, '.');
+    if (ptr_to_compare)
+    {
+      int i = 0;
+      for (i = 0;i < pl->number_of_plugins_found;i++)
+      {
+        char *pl_extension = pl->data[i].info.extension;
+        char *pl_upper_extension = pl->data[i].info.upper_extension;
+
+        if ((strcmp(ptr_to_compare, pl_extension) == 0) ||
+            (strcmp(ptr_to_compare, pl_upper_extension) == 0))
+        {
+          return SPLT_TRUE;
+        }
+      }
+    }
+  }
+
+  return SPLT_FALSE;
+}
+
