@@ -33,6 +33,10 @@
 static char *splt_tu_get_replaced_with_tags(const char *word,
     const splt_tags *tags, int track, int *err, int replace_tags_in_tags);
 static splt_tags *splt_tu_get_tags_to_replace_in_tags(splt_state *state);
+static int splt_tu_set_on_tags_field(splt_tags *tags,
+    int tags_field, const void *data);
+static void splt_tu_set_empty_tags(splt_state *state, int index);
+static void splt_tu_free_one_tags(splt_tags *tags);
 
 void splt_tu_free_original_tags(splt_state *state)
 {
@@ -71,7 +75,7 @@ void splt_tu_auto_increment_tracknumber(splt_state *state)
   int current_split = splt_t_get_current_split_file_number(state) - 1;
   int old_current_split = current_split;
 
-  int remaining_tags_like_x = splt_t_get_int_option(state, SPLT_OPT_ALL_REMAINING_TAGS_LIKE_X); 
+  int remaining_tags_like_x = splt_o_get_int_option(state, SPLT_OPT_ALL_REMAINING_TAGS_LIKE_X); 
   if (remaining_tags_like_x != -1)
   {
     if (current_split >= state->split.real_tagsnumber)
@@ -79,7 +83,7 @@ void splt_tu_auto_increment_tracknumber(splt_state *state)
       current_split = remaining_tags_like_x;
     }
 
-    if (splt_t_get_int_option(state, SPLT_OPT_AUTO_INCREMENT_TRACKNUMBER_TAGS) > 0)
+    if (splt_o_get_int_option(state, SPLT_OPT_AUTO_INCREMENT_TRACKNUMBER_TAGS) > 0)
     {
       if (current_split == remaining_tags_like_x)
       {
@@ -87,8 +91,13 @@ void splt_tu_auto_increment_tracknumber(splt_state *state)
             (old_current_split-1 < state->split.real_tagsnumber) && 
             (old_current_split != remaining_tags_like_x))
         {
-          int previous_track = splt_tu_get_tags_int_field(state, old_current_split - 1, SPLT_TAGS_TRACK);
-          splt_tu_set_tags_int_field(state, remaining_tags_like_x, SPLT_TAGS_TRACK, previous_track);
+          int *prev_track = (int *)splt_tu_get_tags_field(state, old_current_split - 1, SPLT_TAGS_TRACK);
+          int previous_track = 0;
+          if (prev_track != NULL)
+          {
+            previous_track = *prev_track;
+          }
+          splt_tu_set_tags_field(state, remaining_tags_like_x, SPLT_TAGS_TRACK, &previous_track);
         }
 
         if (old_current_split != current_split)
@@ -96,11 +105,15 @@ void splt_tu_auto_increment_tracknumber(splt_state *state)
           int tracknumber = 1;
           if (splt_tu_tags_exists(state, current_split))
           {
-            tracknumber = splt_tu_get_tags_int_field(state, current_split, SPLT_TAGS_TRACK);
+            int *track = (int *)splt_tu_get_tags_field(state, current_split, SPLT_TAGS_TRACK);
+            if (track != NULL)
+            {
+              tracknumber = *track;
+            }
           }
-          splt_tu_set_tags_int_field(state, current_split, SPLT_TAGS_TRACK, tracknumber+1);
-          splt_tu_set_like_x_tags_field(state, SPLT_TAGS_TRACK, tracknumber+1,
-              NULL, 0x0);
+          int new_tracknumber = tracknumber + 1;
+          splt_tu_set_tags_field(state, current_split, SPLT_TAGS_TRACK, &new_tracknumber);
+          splt_tu_set_like_x_tags_field(state, SPLT_TAGS_TRACK, &new_tracknumber);
         }
       }
     }
@@ -109,7 +122,7 @@ void splt_tu_auto_increment_tracknumber(splt_state *state)
 
 void splt_tu_get_original_tags(splt_state *state, int *err)
 {
-  if (! splt_t_is_stdin(state))
+  if (! splt_io_input_is_stdin(state))
   {
     splt_tu_free_original_tags(state);
     splt_p_set_original_tags(state, err);
@@ -164,43 +177,42 @@ int splt_tu_append_tags(splt_state *state,
   int error = SPLT_OK;
   int old_tagsnumber = state->split.real_tagsnumber;
 
-  error = splt_tu_set_tags_char_field(state,
+  error = splt_tu_set_tags_field(state,
       old_tagsnumber, SPLT_TAGS_TITLE, title);
   if (error != SPLT_OK)
     return error;
 
-  error = splt_tu_set_tags_char_field(state,
+  error = splt_tu_set_tags_field(state,
       old_tagsnumber, SPLT_TAGS_ARTIST, artist);
   if (error != SPLT_OK)
     return error;
 
-  error = splt_tu_set_tags_char_field(state,
+  error = splt_tu_set_tags_field(state,
       old_tagsnumber, SPLT_TAGS_ALBUM, album);
   if (error != SPLT_OK)
     return error;
 
-  error = splt_tu_set_tags_char_field(state,
+  error = splt_tu_set_tags_field(state,
       old_tagsnumber, SPLT_TAGS_PERFORMER, performer);
   if (error != SPLT_OK)
     return error;
 
-  error = splt_tu_set_tags_char_field(state,
+  error = splt_tu_set_tags_field(state,
       old_tagsnumber, SPLT_TAGS_YEAR, year);
   if (error != SPLT_OK)
     return error;
 
-  error = splt_tu_set_tags_char_field(state,
+  error = splt_tu_set_tags_field(state,
       old_tagsnumber, SPLT_TAGS_COMMENT, comment);
   if (error != SPLT_OK)
     return error;
 
-  error = splt_tu_set_tags_int_field(state,
-      old_tagsnumber, SPLT_TAGS_TRACK, track);
+  error = splt_tu_set_tags_field(state,
+      old_tagsnumber, SPLT_TAGS_TRACK, &track);
   if (error != SPLT_OK)
     return error;
 
-  error = splt_tu_set_tags_uchar_field(state,
-      old_tagsnumber, SPLT_TAGS_GENRE, genre);
+  error = splt_tu_set_tags_field(state, old_tagsnumber, SPLT_TAGS_GENRE, &genre);
   return error;
 }
 
@@ -218,57 +230,56 @@ int splt_tu_append_only_non_null_previous_tags(splt_state *state,
   {
     if (title != NULL)
     {
-      error = splt_tu_set_tags_char_field(state,
+      error = splt_tu_set_tags_field(state,
           old_tagsnumber, SPLT_TAGS_TITLE, title);
     }
     if (error != SPLT_OK)
       return error;
     if (artist != NULL)
     {
-      error = splt_tu_set_tags_char_field(state,
+      error = splt_tu_set_tags_field(state,
           old_tagsnumber, SPLT_TAGS_ARTIST, artist);
     }
     if (error != SPLT_OK)
       return error;
     if (album != NULL)
     {
-      error = splt_tu_set_tags_char_field(state,
+      error = splt_tu_set_tags_field(state,
           old_tagsnumber, SPLT_TAGS_ALBUM, album);
     }
     if (error != SPLT_OK)
       return error;
     if (performer != NULL)
     {
-      error = splt_tu_set_tags_char_field(state,
+      error = splt_tu_set_tags_field(state,
           old_tagsnumber, SPLT_TAGS_PERFORMER, performer);
     }
     if (error != SPLT_OK)
       return error;
     if (year != NULL)
     {
-      error = splt_tu_set_tags_char_field(state,
+      error = splt_tu_set_tags_field(state,
           old_tagsnumber, SPLT_TAGS_YEAR, year);
     }
     if (error != SPLT_OK)
       return error;
     if (comment != NULL)
     {
-      error = splt_tu_set_tags_char_field(state,
+      error = splt_tu_set_tags_field(state,
           old_tagsnumber, SPLT_TAGS_COMMENT, comment);
     }
     if (error != SPLT_OK)
       return error;
     if (track != -1)
     {
-      error = splt_tu_set_tags_int_field(state,
-          old_tagsnumber, SPLT_TAGS_TRACK, track);
+      error = splt_tu_set_tags_field(state,
+          old_tagsnumber, SPLT_TAGS_TRACK, &track);
     }
     if (error != SPLT_OK)
       return error;
     if (genre != 12)
     {
-      error = splt_tu_set_tags_uchar_field(state,
-          old_tagsnumber, SPLT_TAGS_GENRE, genre);
+      error = splt_tu_set_tags_field(state, old_tagsnumber, SPLT_TAGS_GENRE, &genre);
     }
   }
 
@@ -288,12 +299,6 @@ void splt_tu_reset_tags(splt_tags *tags)
   tags->tags_version = 0;
 }
 
-//-index should not be out of bounds
-static void splt_tu_set_empty_tags(splt_state *state, int index)
-{
-  splt_tu_reset_tags(&state->split.tags[index]);
-}
-
 int splt_tu_new_tags_if_necessary(splt_state *state, int index)
 {
   int error = SPLT_OK;
@@ -302,7 +307,7 @@ int splt_tu_new_tags_if_necessary(splt_state *state, int index)
   {
     if ((index > state->split.real_tagsnumber) || (index < 0))
     {
-      splt_u_error(SPLT_IERROR_INT,__func__, index, NULL);
+      splt_e_error(SPLT_IERROR_INT,__func__, index, NULL);
     }
     else
     {
@@ -322,7 +327,7 @@ int splt_tu_new_tags_if_necessary(splt_state *state, int index)
   {
     if ((index > state->split.real_tagsnumber) || (index < 0))
     {
-      splt_u_error(SPLT_IERROR_INT,__func__, index, NULL);
+      splt_e_error(SPLT_IERROR_INT,__func__, index, NULL);
     }
     else
     {
@@ -358,9 +363,8 @@ int splt_tu_tags_exists(splt_state *state, int index)
   }
 }
 
-//set title, artist, album, year or comment
-int splt_tu_set_tags_char_field(splt_state *state, int index,
-    int tags_field, const char *data)
+int splt_tu_set_tags_field(splt_state *state, int index,
+    int tags_field, const void *data)
 {
   int error = SPLT_OK;
 
@@ -370,226 +374,30 @@ int splt_tu_set_tags_char_field(splt_state *state, int index,
   if ((index >= state->split.real_tagsnumber) || (index < 0))
   {
     error = SPLT_ERROR_INEXISTENT_SPLITPOINT;
-    splt_u_error(SPLT_IERROR_INT,__func__, index, NULL);
+    splt_e_error(SPLT_IERROR_INT,__func__, index, NULL);
     return error;
   }
   else
   {
-    switch(tags_field)
-    {
-      case SPLT_TAGS_TITLE:
-        splt_u_print_debug(state,"Setting title tags at ",index,data);
-        if (state->split.tags[index].title)
-        {
-          free(state->split.tags[index].title);
-          state->split.tags[index].title = NULL;
-        }
-        if (data == NULL)
-        {
-          state->split.tags[index].title = NULL;
-        }
-        else
-        {
-          if ((state->split.tags[index].title = malloc((strlen(data)+1) * 
-                  sizeof(char))) == NULL)
-          {
-            error = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
-          }
-          else
-          {
-            snprintf(state->split.tags[index].title,(strlen(data)+1),"%s", data);
-          }
-        }
-        break;
-      case SPLT_TAGS_ARTIST:
-        splt_u_print_debug(state,"Setting artist tags at ",index,data);
-        if (state->split.tags[index].artist)
-        {
-          free(state->split.tags[index].artist);
-          state->split.tags[index].artist = NULL;
-        }
-        if (data == NULL)
-        {
-          state->split.tags[index].artist = NULL;
-        }
-        else
-        {
-          if ((state->split.tags[index].artist = malloc((strlen(data)+1) * 
-                  sizeof(char))) == NULL)
-          {
-            error = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
-          }
-          else
-          {
-            snprintf(state->split.tags[index].artist,(strlen(data)+1),"%s", data);
-          }
-        }
-        break;
-      case SPLT_TAGS_ALBUM:
-        splt_u_print_debug(state,"Setting album tags at ",index,data);
-        if (state->split.tags[index].album)
-        {
-          free(state->split.tags[index].album);
-          state->split.tags[index].album = NULL;
-        }
-        if (data == NULL)
-        {
-          state->split.tags[index].album = NULL;
-        }
-        else
-        {
-          if ((state->split.tags[index].album = malloc((strlen(data)+1) * 
-                  sizeof(char))) == NULL)
-          {
-            error = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
-          }
-          else
-          {
-            snprintf(state->split.tags[index].album,(strlen(data)+1),"%s", data);
-          }
-        }
-        break;
-      case SPLT_TAGS_YEAR:
-        splt_u_print_debug(state,"Setting year tags at ",index,data);
-        if (state->split.tags[index].year)
-        {
-          free(state->split.tags[index].year);
-          state->split.tags[index].year = NULL;
-        }
-        if (data == NULL)
-        {
-          state->split.tags[index].year = NULL;
-        }
-        else
-        {
-          if ((state->split.tags[index].year = malloc((strlen(data)+1) * 
-                  sizeof(char))) == NULL)
-          {
-            error = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
-          }
-          else
-          {
-            snprintf(state->split.tags[index].year,(strlen(data)+1),"%s", data);
-          }
-        }
-        break;
-      case SPLT_TAGS_COMMENT:
-        if (state->split.tags[index].comment)
-        {
-          free(state->split.tags[index].comment);
-          state->split.tags[index].comment = NULL;
-        }
-        if (data == NULL)
-        {
-          state->split.tags[index].comment = NULL;
-        }
-        else
-        {
-          if ((state->split.tags[index].comment = malloc((strlen(data)+1) * 
-                  sizeof(char))) == NULL)
-          {
-            error = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
-          }
-          else
-          {
-            snprintf(state->split.tags[index].comment,(strlen(data)+1),"%s", data);
-          }
-        }
-        break;
-      case SPLT_TAGS_PERFORMER:
-        splt_u_print_debug(state,"Setting performer tags at ",index,data);
-        if (state->split.tags[index].performer)
-        {
-          free(state->split.tags[index].performer);
-          state->split.tags[index].performer = NULL;
-        }
-        if (data == NULL)
-        {
-          state->split.tags[index].performer = NULL;
-        }
-        else
-        {
-          if ((state->split.tags[index].performer = malloc((strlen(data)+1) * 
-                  sizeof(char))) == NULL)
-          {
-            error = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
-          }
-          else
-          {
-            snprintf(state->split.tags[index].performer,(strlen(data)+1),"%s", data);
-          }
-        }
-        break;
-      default:
-        break;
-    }
+    splt_tu_set_on_tags_field(&state->split.tags[index], tags_field, data);
   }
 
   if (error != SPLT_OK)
   {
-    splt_u_error(SPLT_IERROR_INT,__func__, index, NULL);
+    splt_e_error(SPLT_IERROR_INT,__func__, index, NULL);
   }
 
   return error;
 }
 
-static int splt_tu_set_tags_field(splt_tags *tags,
-    int tags_field, int int_data, const char *char_data,
-    unsigned char uchar_data)
+int splt_tu_set_like_x_tags_field(splt_state *state, int tags_field, const void *data)
 {
-  int err = SPLT_OK;
-
-  switch (tags_field)
-  {
-    case SPLT_TAGS_TITLE:
-      err = splt_su_copy(char_data, &tags->title);
-      break;
-    case SPLT_TAGS_ARTIST:
-      err = splt_su_copy(char_data, &tags->artist);
-      break;
-    case SPLT_TAGS_ALBUM:
-      err = splt_su_copy(char_data, &tags->album);
-      break;
-    case SPLT_TAGS_YEAR:
-      err = splt_su_copy(char_data, &tags->year);
-      break;
-    case SPLT_TAGS_COMMENT:
-      err = splt_su_copy(char_data, &tags->comment);
-      break;
-    case SPLT_TAGS_PERFORMER:
-      err = splt_su_copy(char_data, &tags->performer);
-      break;
-    case SPLT_TAGS_TRACK:
-      tags->track = int_data;
-      break;
-    case SPLT_TAGS_GENRE:
-      tags->genre = uchar_data;
-      break;
-    case SPLT_TAGS_VERSION:
-      tags->tags_version = int_data;
-      break;
-    default:
-      splt_u_error(SPLT_IERROR_INT,__func__, -500, NULL);
-      break;
-  }
-
-  return err;
+  return splt_tu_set_on_tags_field(&state->split.tags_like_x, tags_field, data);
 }
 
-int splt_tu_set_like_x_tags_field(splt_state *state,
-    int tags_field, int int_data,
-    const char *char_data, unsigned char uchar_data)
+int splt_tu_set_original_tags_field(splt_state *state, int tags_field, const void *data)
 {
-  return splt_tu_set_tags_field(&state->split.tags_like_x, tags_field,
-      int_data, char_data, uchar_data);
-}
-
-int splt_tu_set_original_tags_field(splt_state *state,
-    int tags_field, int int_data,
-    const char *char_data, unsigned char uchar_data)
-{
-  return splt_tu_set_tags_field(&state->original_tags, tags_field,
-      int_data, char_data, uchar_data);
+  return splt_tu_set_on_tags_field(&state->original_tags, tags_field, data);
 }
 
 int splt_tu_set_tags_in_tags(splt_state *state, int current_split)
@@ -622,7 +430,7 @@ int splt_tu_set_tags_in_tags(splt_state *state, int current_split)
     cur_tags->genre = tags->genre;
     cur_tags->tags_version = tags->tags_version;
 
-    int replace_tags_in_tags = splt_t_get_int_option(state, SPLT_OPT_REPLACE_TAGS_IN_TAGS);
+    int replace_tags_in_tags = splt_o_get_int_option(state, SPLT_OPT_REPLACE_TAGS_IN_TAGS);
 
     char *t = splt_tu_get_replaced_with_tags(tags->title, tags, track, &err, replace_tags_in_tags);
     if (err != SPLT_OK) { return err; }
@@ -645,87 +453,6 @@ int splt_tu_set_tags_in_tags(splt_state *state, int current_split)
   return err;
 }
 
-//set track number
-int splt_tu_set_tags_int_field(splt_state *state, int index,
-    int tags_field, int data)
-{
-  int error = SPLT_OK;
-
-  error = splt_tu_new_tags_if_necessary(state,index);
-
-  if (error != SPLT_OK)
-  {
-    splt_u_error(SPLT_IERROR_INT,__func__, index, NULL);
-    return error;
-  }
-
-  if ((index >= state->split.real_tagsnumber)
-      || (index < 0))
-  {
-    error = SPLT_ERROR_INEXISTENT_SPLITPOINT;
-    splt_u_error(SPLT_IERROR_INT,__func__, index, NULL);
-    return error;
-  }
-  else
-  {
-    char temp[100] = { '\0' };
-    switch (tags_field)
-    {
-      case SPLT_TAGS_TRACK:
-        //debug
-        snprintf(temp,100,"%d",data);
-        splt_u_print_debug(state,"Setting track tags at",index,temp);
-        state->split.tags[index].track = data;
-        break;
-      case SPLT_TAGS_VERSION:
-        splt_u_print_debug(state,"Setting tags version at",index,temp);
-        state->split.tags[index].tags_version = data;
-        break;
-      default:
-        break;
-    }
-  }
-
-  return error;
-}
-
-int splt_tu_set_tags_uchar_field(splt_state *state, int index,
-    int tags_field, unsigned char data)
-{
-  int error = SPLT_OK;
-
-  error = splt_tu_new_tags_if_necessary(state,index);
-  if (error < 0)
-  {
-    splt_u_error(SPLT_IERROR_INT,__func__, index, NULL);
-    return error;
-  }
-
-  if ((index >= state->split.real_tagsnumber) || (index < 0))
-  {
-    error = SPLT_ERROR_INEXISTENT_SPLITPOINT;
-    splt_u_error(SPLT_IERROR_INT,__func__, index, NULL);
-    return error;
-  }
-  else
-  {
-    char temp[100] = { '\0' };
-    switch (tags_field)
-    {
-      case SPLT_TAGS_GENRE:
-        //debug
-        snprintf(temp,100,"%uc",data);
-        splt_u_print_debug(state,"Setting genre tags at",index,temp);
-        state->split.tags[index].genre = data;
-        break;
-      default:
-        break;
-    }
-  }
-
-  return error;
-}
-
 splt_tags *splt_tu_get_tags(splt_state *state, int *tags_number)
 {
   *tags_number = state->split.real_tagsnumber;
@@ -747,11 +474,11 @@ splt_tags splt_tu_get_last_tags(splt_state *state)
   return state->split.tags[state->split.real_tagsnumber-1];
 }
 
-char *splt_tu_get_tags_char_field(splt_state *state, int index, int tags_field)
+void *splt_tu_get_tags_field(splt_state *state, int index, int tags_field)
 {
   if ((index >= state->split.real_tagsnumber) || (index < 0))
   {
-    splt_u_error(SPLT_IERROR_INT,__func__, index, NULL);
+    splt_e_error(SPLT_IERROR_INT,__func__, index, NULL);
     return NULL;
   }
   else
@@ -776,65 +503,295 @@ char *splt_tu_get_tags_char_field(splt_state *state, int index, int tags_field)
       case SPLT_TAGS_PERFORMER:
         return state->split.tags[index].performer;
         break;
-      default:
-        splt_u_error(SPLT_IERROR_INT,__func__, index, NULL);
-        return NULL;
+      case SPLT_TAGS_TRACK:
+        return &state->split.tags[index].track;
         break;
+      case SPLT_TAGS_VERSION:
+        return &state->split.tags[index].tags_version;
+        break;
+      case SPLT_TAGS_GENRE:
+        return &state->split.tags[index].genre;
+        break;
+      default:
+        splt_e_error(SPLT_IERROR_INT,__func__, index, NULL);
+        return NULL;
     }
   }
 
   return NULL;
 }
 
-int splt_tu_get_tags_int_field(splt_state *state, int index, int tags_field)
+splt_tags *splt_tu_get_tags_like_x(splt_state *state)
 {
-  if ((index >= state->split.real_tagsnumber) || (index < 0))
-  {
-    splt_u_error(SPLT_IERROR_INT,__func__, index, NULL);
-    return 0;
-  }
-  else
-  {
-    switch (tags_field)
-    {
-      case SPLT_TAGS_TRACK:
-        return state->split.tags[index].track;
-        break;
-      case SPLT_TAGS_VERSION:
-        return state->split.tags[index].tags_version;
-        break;
-      default:
-        splt_u_error(SPLT_IERROR_INT,__func__, index, NULL);
-        break;
-    }
-  }
-
-  return 0;
+  return &state->split.tags_like_x;
 }
 
-unsigned char splt_tu_get_tags_uchar_field(splt_state *state, int index,
-    int tags_field)
+void splt_tu_free_tags(splt_state *state)
 {
-  if ((index >= state->split.real_tagsnumber)
-      || (index < 0))
+  if (state->split.tags)
   {
-    splt_u_error(SPLT_IERROR_INT,__func__, index, NULL);
-    return 0x0;
-  }
-  else
-  {
-    switch (tags_field)
+    int i = 0;
+    for (i = 0; i < state->split.real_tagsnumber; i++)
     {
-      case SPLT_TAGS_GENRE:
-        return state->split.tags[index].genre;
-        break;
-      default:
-        splt_u_error(SPLT_IERROR_INT,__func__, index, NULL);
-        break;
+      splt_tu_free_one_tags(&state->split.tags[i]);
+    }
+    free(state->split.tags);
+    state->split.tags = NULL;
+  }
+
+  state->split.real_tagsnumber = 0;
+
+  splt_tu_free_one_tags(splt_tu_get_tags_like_x(state));
+}
+
+splt_tags *splt_tu_get_current_tags(splt_state *state)
+{
+  int current_tags_number = splt_t_get_current_split_file_number(state) - 1;
+
+  int remaining_tags_like_x = splt_o_get_int_option(state, SPLT_OPT_ALL_REMAINING_TAGS_LIKE_X); 
+  if ((current_tags_number >= state->split.real_tagsnumber) &&
+      (remaining_tags_like_x != -1))
+  {
+    current_tags_number = remaining_tags_like_x; 
+  }
+
+  return splt_tu_get_tags_at(state, current_tags_number);
+}
+
+char *splt_tu_get_artist_or_performer_ptr(splt_tags *tags)
+{
+  if (!tags)
+  {
+    return NULL;
+  }
+
+  char *artist_or_performer = tags->artist;
+
+  if (tags->performer == NULL)
+  {
+    return artist_or_performer;
+  }
+
+  if (tags->performer[0] != '\0')
+  {
+    return tags->performer;
+  }
+
+  return artist_or_performer;
+}
+
+int splt_tu_copy_first_common_tags_on_all_tracks(splt_state *state, int tracks)
+{
+  int err = SPLT_OK;
+
+  char *artist0 = NULL;
+  char *album0 = NULL;
+  char *year0 = NULL;
+
+  char *first_artist = (char *)splt_tu_get_tags_field(state, 0, SPLT_TAGS_ARTIST);
+  err = splt_su_copy(first_artist, &artist0);
+  if (err < 0) { goto function_end; }
+
+  char *first_album = (char *)splt_tu_get_tags_field(state, 0, SPLT_TAGS_ALBUM);
+  err = splt_su_copy(first_album, &album0);
+  if (err < 0) { goto function_end; }
+
+  char *first_year = (char *)splt_tu_get_tags_field(state, 0, SPLT_TAGS_YEAR);
+  err = splt_su_copy(first_year, &year0);
+  if (err < 0) { goto function_end; }
+
+  unsigned char genre0 = 0x0;
+  unsigned char *g = (unsigned char *)splt_tu_get_tags_field(state, 0, SPLT_TAGS_GENRE);
+  if (g != NULL) {
+    genre0 = *g;
+  }
+
+  int i = 0;
+  for (i = 0; i < tracks;i++)
+  {
+    if (i != 0)
+    {
+      err = splt_tu_set_tags_field(state, i, SPLT_TAGS_ARTIST, artist0);
+      if (err != SPLT_OK) { break; }
+
+      err = splt_tu_set_tags_field(state, i, SPLT_TAGS_ALBUM, album0);
+      if (err != SPLT_OK) { break; }
+
+      err = splt_tu_set_tags_field(state, i, SPLT_TAGS_YEAR, year0);
+      if (err != SPLT_OK) { break; }
+
+      err = splt_tu_set_tags_field(state, i, SPLT_TAGS_GENRE, &genre0);
+      if (err != SPLT_OK) { break; }
     }
   }
 
-  return 0x0;
+function_end:
+  if (artist0)
+  {
+    free(artist0);
+    artist0 = NULL;
+  }
+  if (album0)
+  {
+    free(album0);
+    album0 = NULL;
+  }
+  if (year0)
+  {
+    free(year0);
+    year0 = NULL;
+  }
+
+  return err;
+}
+
+static splt_tags *splt_tu_get_tags_to_replace_in_tags(splt_state *state)
+{
+  int current_tags_number = splt_t_get_current_split_file_number(state) - 1;
+
+  int remaining_tags_like_x = splt_o_get_int_option(state, SPLT_OPT_ALL_REMAINING_TAGS_LIKE_X); 
+  if ((current_tags_number >= state->split.real_tagsnumber) &&
+      (remaining_tags_like_x != -1))
+  {
+    return splt_tu_get_tags_like_x(state);
+  }
+
+  return splt_tu_get_tags_at(state, current_tags_number);
+}
+
+static char *splt_tu_get_replaced_with_tags(const char *word,
+    const splt_tags *tags, int track, int *error, int replace_tags_in_tags)
+{
+  int err = SPLT_OK;
+
+  char *word_with_tags = NULL;
+
+  if (!replace_tags_in_tags)
+  {
+    err = splt_su_copy(word, &word_with_tags);
+    if (err < 0) { *error = err; }
+    return word_with_tags;
+  }
+
+  char buffer[256] = { '\0' };
+
+  if (word == NULL)
+  {
+    return NULL;
+  }
+
+  const char *title = tags->title;
+  const char *artist = tags->artist;
+  const char *album= tags->album;
+  const char *performer = tags->performer;
+  const char *year = tags->year;
+  const char *comment = tags->comment;
+
+  int counter = 0;
+  const char *ptr = NULL;
+  for (ptr = word; *ptr != '\0'; ptr++)
+  {
+    if (*ptr == '@')
+    {
+      err = splt_su_append(&word_with_tags, buffer, counter, NULL);
+      if (err != SPLT_OK) { goto error; }
+
+      memset(buffer, 256, '\0');
+      counter = 0;
+
+      ptr++;
+
+      switch (*ptr)
+      {
+        case 'a':
+          if (artist != NULL)
+          {
+            err = splt_su_append_str(&word_with_tags, artist, NULL);
+            if (err != SPLT_OK) { goto error; }
+          }
+          break;
+        case 'p':
+          if (performer != NULL)
+          {
+            err = splt_su_append_str(&word_with_tags, performer, NULL);
+            if (err != SPLT_OK) { goto error; }
+          }
+          break;
+        case 'b':
+          if (album != NULL)
+          {
+            err = splt_su_append_str(&word_with_tags, album, NULL);
+            if (err != SPLT_OK) { goto error; }
+          }
+          break;
+        case 't':
+          if (title != NULL)
+          {
+            err = splt_su_append_str(&word_with_tags, title, NULL);
+            if (err != SPLT_OK) { goto error; }
+          }
+          break;
+        case 'c':
+          if (comment != NULL)
+          {
+            err = splt_su_append_str(&word_with_tags, comment, NULL);
+            if (err != SPLT_OK) { goto error; }
+          }
+          break;
+        case 'y':
+          if (year != NULL)
+          {
+            err = splt_su_append(&word_with_tags, year, NULL);
+            if (err != SPLT_OK) { goto error; }
+          }
+          break;
+        case 'N':
+        case 'n':
+          ;
+          char track_str[10] = { '\0' };
+          snprintf(track_str, 10, "%d",track);
+          err = splt_su_append_str(&word_with_tags, track_str, NULL);
+          if (err != SPLT_OK) { goto error; }
+          break;
+        case '@':
+          err = splt_su_append_str(&word_with_tags, "@", NULL);
+          if (err != SPLT_OK) { goto error; }
+          break;
+        default:
+          err = splt_su_append(&word_with_tags, (ptr-1), 2, NULL);
+          if (err != SPLT_OK) { goto error; }
+          break;
+      }
+    }
+    else
+    {
+      buffer[counter] = *ptr;
+      counter++;
+
+      if (counter == 255)
+      {
+        err = splt_su_append(&word_with_tags, buffer, counter, NULL);
+        if (err != SPLT_OK) { goto error; }
+        memset(buffer, 256, '\0');
+        counter = 0;
+      }
+    }
+  }
+
+  err = splt_su_append(&word_with_tags, buffer, counter, NULL);
+  if (err != SPLT_OK) { goto error; }
+
+  return word_with_tags;
+
+error:
+  if (word_with_tags)
+  {
+    free(word_with_tags);
+  }
+
+  *error = err;
+
+  return NULL;
 }
 
 static void splt_tu_free_one_tags(splt_tags *tags)
@@ -874,194 +831,50 @@ static void splt_tu_free_one_tags(splt_tags *tags)
   }
 }
 
-splt_tags *splt_tu_get_tags_like_x(splt_state *state)
+static void splt_tu_set_empty_tags(splt_state *state, int index)
 {
-  return &state->split.tags_like_x;
+  splt_tu_reset_tags(&state->split.tags[index]);
 }
 
-void splt_tu_free_tags(splt_state *state)
-{
-  if (state->split.tags)
-  {
-    int i = 0;
-    for (i = 0; i < state->split.real_tagsnumber; i++)
-    {
-      splt_tu_free_one_tags(&state->split.tags[i]);
-    }
-    free(state->split.tags);
-    state->split.tags = NULL;
-  }
-
-  state->split.real_tagsnumber = 0;
-
-  splt_tu_free_one_tags(splt_tu_get_tags_like_x(state));
-}
-
-splt_tags *splt_tu_get_current_tags(splt_state *state)
-{
-  int current_tags_number = splt_t_get_current_split_file_number(state) - 1;
-
-  int remaining_tags_like_x = splt_t_get_int_option(state, SPLT_OPT_ALL_REMAINING_TAGS_LIKE_X); 
-  if ((current_tags_number >= state->split.real_tagsnumber) &&
-      (remaining_tags_like_x != -1))
-  {
-    current_tags_number = remaining_tags_like_x; 
-  }
-
-  return splt_tu_get_tags_at(state, current_tags_number);
-}
-
-static splt_tags *splt_tu_get_tags_to_replace_in_tags(splt_state *state)
-{
-  int current_tags_number = splt_t_get_current_split_file_number(state) - 1;
-
-  int remaining_tags_like_x = splt_t_get_int_option(state, SPLT_OPT_ALL_REMAINING_TAGS_LIKE_X); 
-  if ((current_tags_number >= state->split.real_tagsnumber) &&
-      (remaining_tags_like_x != -1))
-  {
-    return splt_tu_get_tags_like_x(state);
-  }
-
-  return splt_tu_get_tags_at(state, current_tags_number);
-}
-
-static char *splt_tu_get_replaced_with_tags(const char *word,
-    const splt_tags *tags, int track, int *error, int replace_tags_in_tags)
+static int splt_tu_set_on_tags_field(splt_tags *tags,
+    int tags_field, const void *data)
 {
   int err = SPLT_OK;
 
-  if (!replace_tags_in_tags)
+  switch (tags_field)
   {
-    return splt_su_safe_strdup(word, error);
+    case SPLT_TAGS_TITLE:
+      err = splt_su_copy((char *)data, &tags->title);
+      break;
+    case SPLT_TAGS_ARTIST:
+      err = splt_su_copy((char *)data, &tags->artist);
+      break;
+    case SPLT_TAGS_ALBUM:
+      err = splt_su_copy((char *)data, &tags->album);
+      break;
+    case SPLT_TAGS_YEAR:
+      err = splt_su_copy((char *)data, &tags->year);
+      break;
+    case SPLT_TAGS_COMMENT:
+      err = splt_su_copy((char *)data, &tags->comment);
+      break;
+    case SPLT_TAGS_PERFORMER:
+      err = splt_su_copy((char *)data, &tags->performer);
+      break;
+    case SPLT_TAGS_TRACK:
+      tags->track = *((int *)data);
+      break;
+    case SPLT_TAGS_GENRE:
+      tags->genre = *((unsigned char *)data);
+      break;
+    case SPLT_TAGS_VERSION:
+      tags->tags_version = *((int *)data);
+      break;
+    default:
+      splt_e_error(SPLT_IERROR_INT,__func__, -500, NULL);
+      break;
   }
 
-  char *word_with_tags = NULL;
-  size_t word_with_tags_size = 0;
-
-  char buffer[256] = { '\0' };
-
-  if (word == NULL)
-  {
-    return NULL;
-  }
-
-  const char *title = tags->title;
-  const char *artist = tags->artist;
-  const char *album= tags->album;
-  const char *performer = tags->performer;
-  const char *year = tags->year;
-  const char *comment = tags->comment;
-
-  int counter = 0;
-  const char *ptr = NULL;
-  for (ptr = word; *ptr != '\0'; ptr++)
-  {
-    if (*ptr == '@')
-    {
-      err = splt_su_append(&word_with_tags, &word_with_tags_size, buffer, counter);
-      if (err != SPLT_OK) { goto error; }
-      memset(buffer, 256, '\0');
-      counter = 0;
-
-      ptr++;
-
-      switch (*ptr)
-      {
-        case 'a':
-          if (artist != NULL)
-          {
-            err = splt_su_append(&word_with_tags, &word_with_tags_size,
-                artist, strlen(artist));
-            if (err != SPLT_OK) { goto error; }
-          }
-          break;
-        case 'p':
-          if (performer != NULL)
-          {
-            err = splt_su_append(&word_with_tags, &word_with_tags_size,
-                performer, strlen(performer));
-            if (err != SPLT_OK) { goto error; }
-          }
-          break;
-        case 'b':
-          if (album != NULL)
-          {
-            err = splt_su_append(&word_with_tags, &word_with_tags_size,
-                album, strlen(album));
-            if (err != SPLT_OK) { goto error; }
-          }
-          break;
-        case 't':
-          if (title != NULL)
-          {
-            err = splt_su_append(&word_with_tags, &word_with_tags_size,
-                title, strlen(title));
-            if (err != SPLT_OK) { goto error; }
-          }
-          break;
-        case 'c':
-          if (comment != NULL)
-          {
-            err = splt_su_append(&word_with_tags, &word_with_tags_size,
-                comment, strlen(comment));
-            if (err != SPLT_OK) { goto error; }
-          }
-          break;
-        case 'y':
-          if (year != NULL)
-          {
-            err = splt_su_append(&word_with_tags, &word_with_tags_size,
-                year, strlen(year));
-            if (err != SPLT_OK) { goto error; }
-          }
-          break;
-        case 'N':
-        case 'n':
-          ;
-          char track_str[10] = { '\0' };
-          snprintf(track_str, 10, "%d",track);
-          err = splt_su_append(&word_with_tags, &word_with_tags_size,
-              track_str, strlen(track_str));
-          if (err != SPLT_OK) { goto error; }
-          break;
-        case '@':
-          err = splt_su_append(&word_with_tags, &word_with_tags_size, "@", 1);
-          if (err != SPLT_OK) { goto error; }
-          break;
-        default:
-          err = splt_su_append(&word_with_tags, &word_with_tags_size, (ptr-1), 2);
-          if (err != SPLT_OK) { goto error; }
-          break;
-      }
-    }
-    else
-    {
-      buffer[counter] = *ptr;
-      counter++;
-
-      if (counter == 255)
-      {
-        err = splt_su_append(&word_with_tags, &word_with_tags_size, buffer, counter);
-        if (err != SPLT_OK) { goto error; }
-        memset(buffer, 256, '\0');
-        counter = 0;
-      }
-    }
-  }
-
-  err = splt_su_append(&word_with_tags, &word_with_tags_size, buffer, counter);
-  if (err != SPLT_OK) { goto error; }
-
-  return word_with_tags;
-
-error:
-  if (word_with_tags)
-  {
-    free(word_with_tags);
-  }
-
-  *error = err;
-
-  return NULL;
+  return err;
 }
 
